import React from 'react';
import { TableProps } from '@material-ui/core/Table';
import { TableBodyProps } from '@material-ui/core/TableBody';
import { TableCellProps } from '@material-ui/core/TableCell';
import { TableHeadProps } from '@material-ui/core/TableHead';
import { TablePaginationProps } from '@material-ui/core/TablePagination';
import { TableRowProps } from '@material-ui/core/TableRow';
import { getHeaders, getColumns } from './utils';
declare type ResolvePropType<T> = T | ((obj: {
    rowData: T;
    column: ColumnDef<T>;
}) => T | void);
export declare const useStyles: (props?: any) => Record<"container" | "tableWrapper" | "cellSelected" | "cellHovered", string>;
export declare type ColumnDef<T = any> = {
    name: string;
    header?: string | React.ReactNode;
    cell?: (data: T, index: number) => React.ReactNode;
    cellProps?: ResolvePropType<TableCellProps>;
    onClick?: TableCellProps['onClick'];
    onHeaderClick?: boolean | ((obj: {
        column: ColumnDef<T>;
    }) => void);
    headerCellProps?: TableCellProps;
    bodyCellProps?: TableCellProps;
    orderBy?: string | boolean | ((a: any, b: any) => number);
    columns?: ColumnDef<T>[];
};
export declare type MuiTableProps<T = any> = {
    data: T[] | null;
    columns: ColumnDef<T>[];
    bodyProps?: TableBodyProps;
    containerProps?: any;
    includeHeaders?: boolean;
    headerProps?: TableHeadProps;
    rowProps?: ResolvePropType<TableRowProps>;
    headerRowProps?: ResolvePropType<TableRowProps>;
    headerCellProps?: ResolvePropType<TableCellProps>;
    bodyRowProps?: ResolvePropType<TableRowProps>;
    bodyCellProps?: ResolvePropType<TableCellProps>;
    cellProps?: ResolvePropType<TableCellProps>;
    onHeaderClick?: (obj: {
        column: ColumnDef<T>;
    }) => void;
    onCellClick?: (obj: {
        rowData: T;
        column: ColumnDef<T>;
    }) => void;
    orderBy?: string;
    orderDirection?: 'asc' | 'desc';
    pagination?: TablePaginationProps;
    addPlaceholderRows?: boolean;
    tableWrapperProps?: React.HTMLAttributes<HTMLDivElement>;
    isCellHovered?: (obj: {
        column: ColumnDef<T>;
        rowData: T | null;
        hoveredColumn: ColumnDef<T> | null;
        hoveredRowData: T | null;
    }) => boolean;
    isCellSelected?: (obj: {
        column: ColumnDef<T>;
        rowData: T | null;
    }) => boolean;
    classes?: {
        container?: string;
        tableWrapper?: string;
        cellHovered?: string;
        cellSelected?: string;
    };
} & TableProps;
declare function MuiTable<T = any>(props: MuiTableProps<T>): JSX.Element;
export { getHeaders, getColumns };
export default MuiTable;
